@@ -39,7 +39,8 @@
 #include "hotkeys_tree_view.h"
 #include "khotkeysglobal.h"
 
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
+#include <QDBusError>
 
 #include <KAboutData>
 #include <QDebug>
@@ -265,9 +266,9 @@ void KCMHotkeys::save()
 
 KCMHotkeysPrivate::KCMHotkeysPrivate( KCMHotkeys *host )
     : Ui::KCMHotkeysWidget()
-     ,model(NULL)
+     ,model(nullptr)
      ,q(host)
-     ,current(NULL)
+     ,current(nullptr)
     {
     setupUi(q);
 
