@@ -20,9 +20,9 @@
 #ifndef _TRIGGERS_H_
 #define _TRIGGERS_H_
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QtCore/QUuid>
+#include <QList>
+#include <QMap>
+#include <QUuid>
 
 #include <KShortcut>
 
@@ -244,7 +244,7 @@ class Q_DECL_EXPORT WindowTrigger : public QObject, public Trigger
 
         WindowTrigger(
                 ActionData* data,
-                Windowdef_list* windowslist = NULL,
+                Windowdef_list* windowslist = nullptr,
                 WindowEvents window_actions = 0 );
 
         void setOnWindowEvents(WindowEvents events);
